@@ -1,5 +1,3 @@
-context("Dissimilarity function")
-
 test_that("Dissimilarity function is running correctly", {
   library(PReMiuM)
   library(testthat)
@@ -10,6 +8,11 @@ test_that("Dissimilarity function is running correctly", {
                        nSweeps=1, nBurn=0, data=inputs$inputData, output="output", 
                        covNames=inputs$covNames,nClusInit=15, seed=12345)
   dissimObj<-calcDissimilarityMatrix(runInfoObj)
-  expect_equal(dissimObj$disSimMat[3], 0)
+  expect_equal(head(dissimObj$disSimMat,10),c(1,0, 1, 1, 1, 0, 1, 1, 1, 1))
+  expect_equal(tail(dissimObj$disSimMat,10),c(1, 1, 1, 1, 1, 1, 1, 0, 1, 1))
+  expect_equal(dissimObj$disSimMat[20304:20306],c(1,1,0))
+  expect_equal(length(dissimObj$disSimMat),499500)
+  clusObj<-calcOptimalClustering(dissimObj)
+  expect_equal(clusObj$clusterSizes,c(96, 92, 47, 48, 79, 71, 68, 88, 68, 58, 73, 25, 64, 60, 63))
 })
 
